@@ -44,7 +44,7 @@ def create_app(name: str) -> Flask:
         loader.load_apis(app)
         loader.load_error_handlers(app)
         loader.load_commands(app)
-        loader.load_services(app)
+        loader.load_tasks(app)
         loader.load_docs(app)
         loader.load_apps(app)
 
