@@ -5,7 +5,7 @@ def get():
     return jsonify(text="welcome :')")
 
 
-docs = {"tags": ["${name}"]}
-endpoint = "${url_prefix}"
-url_prefix = "/${url_prefix}"
+docs = {"tags": ["{{name}}"]}
+endpoint = "{{url_prefix}}"
+url_prefix = "/{{url_prefix}}"
 routes = [("/get", get, ["GET"])]
